package user

import (
	"encoding/json"
	"fmt"
	"os"
)

func NewUser(id, name, role string) *User {
	return &User{
		Id:   id,
		Name: name,
		Role: role,
	}
}

func NewUserFromFile(fileName string) (*User, error) {
	jsonBytes, err := os.ReadFile(fileName)
	if err != nil {
		return nil, err
	}

	var usr User
	if err := json.Unmarshal(jsonBytes, &usr); err != nil {
		return nil, fmt.Errorf("%s: %v\n", fileName, err)
	} else {
		return &usr, nil
	}
}

func (user *User) IsPlayer() bool {
	return true
}

func (user *User) IsGamemaster() bool {
	return user.Role == ROLE_GAMEMASTER || user.Role == ROLE_ADMIN
}

func (user *User) IsAdmin() bool {
	return user.Role == ROLE_ADMIN
}
